OfferInfo class

Inheritance
  • Object
  • GeneratedMessage
  • OfferInfo

Constructors

OfferInfo({String? id, String? direction, String? price, bool? useMarketBasedPrice, double? marketPriceMarginPct, Int64? amount, Int64? minAmount, double? makerFeePct, double? takerFeePct, double? penaltyFeePct, double? buyerSecurityDepositPct, double? sellerSecurityDepositPct, String? volume, String? minVolume, String? triggerPrice, String? paymentAccountId, String? paymentMethodId, String? paymentMethodShortName, String? baseCurrencyCode, String? counterCurrencyCode, Int64? date, String? state, bool? isActivated, bool? isMyOffer, String? ownerNodeAddress, String? pubKeyRing, String? versionNr, int? protocolVersion, String? arbitratorSigner, String? splitOutputTxHash, Int64? splitOutputTxFee})
factory
OfferInfo.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
OfferInfo.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

amount ↔ Int64
getter/setter pair
arbitratorSigner ↔ String
getter/setter pair
baseCurrencyCode ↔ String
getter/setter pair
buyerSecurityDepositPct ↔ double
getter/setter pair
counterCurrencyCode ↔ String
getter/setter pair
date ↔ Int64
getter/setter pair
direction ↔ String
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ String
getter/setter pair
info_ → BuilderInfo
no setteroverride
isActivated ↔ bool
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isMyOffer ↔ bool
getter/setter pair
makerFeePct ↔ double
getter/setter pair
marketPriceMarginPct ↔ double
getter/setter pair
minAmount ↔ Int64
getter/setter pair
minVolume ↔ String
getter/setter pair
ownerNodeAddress ↔ String
getter/setter pair
paymentAccountId ↔ String
getter/setter pair
paymentMethodId ↔ String
getter/setter pair
paymentMethodShortName ↔ String
getter/setter pair
penaltyFeePct ↔ double
getter/setter pair
price ↔ String
getter/setter pair
protocolVersion ↔ int
getter/setter pair
pubKeyRing ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerSecurityDepositPct ↔ double
getter/setter pair
splitOutputTxFee ↔ Int64
getter/setter pair
splitOutputTxHash ↔ String
getter/setter pair
state ↔ String
getter/setter pair
takerFeePct ↔ double
getter/setter pair
triggerPrice ↔ String
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
useMarketBasedPrice ↔ bool
getter/setter pair
versionNr ↔ String
getter/setter pair
volume ↔ String
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAmount() → void
clearArbitratorSigner() → void
clearBaseCurrencyCode() → void
clearBuyerSecurityDepositPct() → void
clearCounterCurrencyCode() → void
clearDate() → void
clearDirection() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearIsActivated() → void
clearIsMyOffer() → void
clearMakerFeePct() → void
clearMarketPriceMarginPct() → void
clearMinAmount() → void
clearMinVolume() → void
clearOwnerNodeAddress() → void
clearPaymentAccountId() → void
clearPaymentMethodId() → void
clearPaymentMethodShortName() → void
clearPenaltyFeePct() → void
clearPrice() → void
clearProtocolVersion() → void
clearPubKeyRing() → void
clearSellerSecurityDepositPct() → void
clearSplitOutputTxFee() → void
clearSplitOutputTxHash() → void
clearState() → void
clearTakerFeePct() → void
clearTriggerPrice() → void
clearUseMarketBasedPrice() → void
clearVersionNr() → void
clearVolume() → void
clone() → OfferInfo
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(OfferInfo)) → OfferInfo
Apply updates to a copy of this message.
override
createEmptyInstance() → OfferInfo
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAmount() → bool
hasArbitratorSigner() → bool
hasBaseCurrencyCode() → bool
hasBuyerSecurityDepositPct() → bool
hasCounterCurrencyCode() → bool
hasDate() → bool
hasDirection() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasId() → bool
hasIsActivated() → bool
hasIsMyOffer() → bool
hasMakerFeePct() → bool
hasMarketPriceMarginPct() → bool
hasMinAmount() → bool
hasMinVolume() → bool
hasOwnerNodeAddress() → bool
hasPaymentAccountId() → bool
hasPaymentMethodId() → bool
hasPaymentMethodShortName() → bool
hasPenaltyFeePct() → bool
hasPrice() → bool
hasProtocolVersion() → bool
hasPubKeyRing() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSellerSecurityDepositPct() → bool
hasSplitOutputTxFee() → bool
hasSplitOutputTxHash() → bool
hasState() → bool
hasTakerFeePct() → bool
hasTriggerPrice() → bool
hasUseMarketBasedPrice() → bool
hasVersionNr() → bool
hasVolume() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → OfferInfo
createRepeated() → PbList<OfferInfo>
getDefault() → OfferInfo