Dispute class

Inheritance
  • Object
  • GeneratedMessage
  • Dispute

Constructors

Dispute({String? tradeId, String? id, int? traderId, bool? isOpener, bool? disputeOpenerIsBuyer, bool? disputeOpenerIsMaker, Int64? openingDate, PubKeyRing? traderPubKeyRing, Int64? tradeDate, Contract? contract, List<int>? contractHash, List<int>? payoutTxSerialized, String? payoutTxId, String? contractAsJson, List<int>? makerContractSignature, List<int>? takerContractSignature, PaymentAccountPayload? makerPaymentAccountPayload, PaymentAccountPayload? takerPaymentAccountPayload, PubKeyRing? agentPubKeyRing, bool? isSupportTicket, Iterable<ChatMessage>? chatMessage, bool? isClosed, DisputeResult? disputeResult, String? disputePayoutTxId, SupportType? supportType, String? mediatorsDisputeResult, String? delayedPayoutTxId, String? donationAddressOfDelayedPayoutTx, Dispute_State? state, Int64? tradePeriodEnd, Map<String, String>? extraData})
factory
Dispute.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Dispute.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

agentPubKeyRing ↔ PubKeyRing
getter/setter pair
chatMessage → List<ChatMessage>
no setter
contract ↔ Contract
getter/setter pair
contractAsJson ↔ String
getter/setter pair
contractHash ↔ List<int>
getter/setter pair
delayedPayoutTxId ↔ String
getter/setter pair
disputeOpenerIsBuyer ↔ bool
getter/setter pair
disputeOpenerIsMaker ↔ bool
getter/setter pair
disputePayoutTxId ↔ String
getter/setter pair
disputeResult ↔ DisputeResult
getter/setter pair
donationAddressOfDelayedPayoutTx ↔ String
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
extraData → Map<String, String>
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ String
getter/setter pair
info_ → BuilderInfo
no setteroverride
isClosed ↔ bool
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isOpener ↔ bool
getter/setter pair
isSupportTicket ↔ bool
getter/setter pair
makerContractSignature ↔ List<int>
getter/setter pair
makerPaymentAccountPayload ↔ PaymentAccountPayload
getter/setter pair
mediatorsDisputeResult ↔ String
getter/setter pair
openingDate ↔ Int64
getter/setter pair
payoutTxId ↔ String
getter/setter pair
payoutTxSerialized ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ Dispute_State
getter/setter pair
supportType ↔ SupportType
getter/setter pair
takerContractSignature ↔ List<int>
getter/setter pair
takerPaymentAccountPayload ↔ PaymentAccountPayload
getter/setter pair
tradeDate ↔ Int64
getter/setter pair
tradeId ↔ String
getter/setter pair
tradePeriodEnd ↔ Int64
getter/setter pair
traderId ↔ int
getter/setter pair
traderPubKeyRing ↔ PubKeyRing
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAgentPubKeyRing() → void
clearContract() → void
clearContractAsJson() → void
clearContractHash() → void
clearDelayedPayoutTxId() → void
clearDisputeOpenerIsBuyer() → void
clearDisputeOpenerIsMaker() → void
clearDisputePayoutTxId() → void
clearDisputeResult() → void
clearDonationAddressOfDelayedPayoutTx() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearIsClosed() → void
clearIsOpener() → void
clearIsSupportTicket() → void
clearMakerContractSignature() → void
clearMakerPaymentAccountPayload() → void
clearMediatorsDisputeResult() → void
clearOpeningDate() → void
clearPayoutTxId() → void
clearPayoutTxSerialized() → void
clearState() → void
clearSupportType() → void
clearTakerContractSignature() → void
clearTakerPaymentAccountPayload() → void
clearTradeDate() → void
clearTradeId() → void
clearTradePeriodEnd() → void
clearTraderId() → void
clearTraderPubKeyRing() → void
clone() → Dispute
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(Dispute)) → Dispute
Apply updates to a copy of this message.
override
createEmptyInstance() → Dispute
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureAgentPubKeyRing() → PubKeyRing
ensureContract() → Contract
ensureDisputeResult() → DisputeResult
ensureMakerPaymentAccountPayload() → PaymentAccountPayload
ensureTakerPaymentAccountPayload() → PaymentAccountPayload
ensureTraderPubKeyRing() → PubKeyRing
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAgentPubKeyRing() → bool
hasContract() → bool
hasContractAsJson() → bool
hasContractHash() → bool
hasDelayedPayoutTxId() → bool
hasDisputeOpenerIsBuyer() → bool
hasDisputeOpenerIsMaker() → bool
hasDisputePayoutTxId() → bool
hasDisputeResult() → bool
hasDonationAddressOfDelayedPayoutTx() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasId() → bool
hasIsClosed() → bool
hasIsOpener() → bool
hasIsSupportTicket() → bool
hasMakerContractSignature() → bool
hasMakerPaymentAccountPayload() → bool
hasMediatorsDisputeResult() → bool
hasOpeningDate() → bool
hasPayoutTxId() → bool
hasPayoutTxSerialized() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasState() → bool
hasSupportType() → bool
hasTakerContractSignature() → bool
hasTakerPaymentAccountPayload() → bool
hasTradeDate() → bool
hasTradeId() → bool
hasTradePeriodEnd() → bool
hasTraderId() → bool
hasTraderPubKeyRing() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Dispute
createRepeated() → PbList<Dispute>
getDefault() → Dispute