OfferPayload class

Inheritance
  • Object
  • GeneratedMessage
  • OfferPayload

Constructors

OfferPayload({String? id, Int64? date, NodeAddress? ownerNodeAddress, PubKeyRing? pubKeyRing, OfferDirection? direction, Int64? price, double? marketPriceMarginPct, bool? useMarketBasedPrice, Int64? amount, Int64? minAmount, double? makerFeePct, double? takerFeePct, double? penaltyFeePct, double? buyerSecurityDepositPct, double? sellerSecurityDepositPct, String? baseCurrencyCode, String? counterCurrencyCode, String? paymentMethodId, String? makerPaymentAccountId, String? countryCode, Iterable<String>? acceptedCountryCodes, String? bankId, Iterable<String>? acceptedBankIds, String? versionNr, Int64? blockHeightAtOfferCreation, Int64? maxTradeLimit, Int64? maxTradePeriod, bool? useAutoClose, bool? useReOpenAfterAutoClose, Int64? lowerClosePrice, Int64? upperClosePrice, bool? isPrivateOffer, String? hashOfChallenge, Map<String, String>? extraData, int? protocolVersion, NodeAddress? arbitratorSigner, List<int>? arbitratorSignature, Iterable<String>? reserveTxKeyImages})
factory
OfferPayload.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
OfferPayload.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

acceptedBankIds → List<String>
no setter
acceptedCountryCodes → List<String>
no setter
amount ↔ Int64
getter/setter pair
arbitratorSignature ↔ List<int>
getter/setter pair
arbitratorSigner ↔ NodeAddress
getter/setter pair
bankId ↔ String
getter/setter pair
baseCurrencyCode ↔ String
getter/setter pair
blockHeightAtOfferCreation ↔ Int64
getter/setter pair
buyerSecurityDepositPct ↔ double
getter/setter pair
counterCurrencyCode ↔ String
getter/setter pair
countryCode ↔ String
getter/setter pair
date ↔ Int64
getter/setter pair
direction ↔ OfferDirection
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
extraData → Map<String, String>
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hashOfChallenge ↔ String
getter/setter pair
id ↔ String
getter/setter pair
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isPrivateOffer ↔ bool
getter/setter pair
lowerClosePrice ↔ Int64
getter/setter pair
makerFeePct ↔ double
getter/setter pair
makerPaymentAccountId ↔ String
getter/setter pair
marketPriceMarginPct ↔ double
getter/setter pair
maxTradeLimit ↔ Int64
getter/setter pair
maxTradePeriod ↔ Int64
getter/setter pair
minAmount ↔ Int64
getter/setter pair
ownerNodeAddress ↔ NodeAddress
getter/setter pair
paymentMethodId ↔ String
getter/setter pair
penaltyFeePct ↔ double
getter/setter pair
price ↔ Int64
getter/setter pair
protocolVersion ↔ int
getter/setter pair
pubKeyRing ↔ PubKeyRing
getter/setter pair
reserveTxKeyImages → List<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerSecurityDepositPct ↔ double
getter/setter pair
takerFeePct ↔ double
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
upperClosePrice ↔ Int64
getter/setter pair
useAutoClose ↔ bool
getter/setter pair
useMarketBasedPrice ↔ bool
getter/setter pair
useReOpenAfterAutoClose ↔ bool
getter/setter pair
versionNr ↔ String
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAmount() → void
clearArbitratorSignature() → void
clearArbitratorSigner() → void
clearBankId() → void
clearBaseCurrencyCode() → void
clearBlockHeightAtOfferCreation() → void
clearBuyerSecurityDepositPct() → void
clearCounterCurrencyCode() → void
clearCountryCode() → void
clearDate() → void
clearDirection() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHashOfChallenge() → void
clearId() → void
clearIsPrivateOffer() → void
clearLowerClosePrice() → void
clearMakerFeePct() → void
clearMakerPaymentAccountId() → void
clearMarketPriceMarginPct() → void
clearMaxTradeLimit() → void
clearMaxTradePeriod() → void
clearMinAmount() → void
clearOwnerNodeAddress() → void
clearPaymentMethodId() → void
clearPenaltyFeePct() → void
clearPrice() → void
clearProtocolVersion() → void
clearPubKeyRing() → void
clearSellerSecurityDepositPct() → void
clearTakerFeePct() → void
clearUpperClosePrice() → void
clearUseAutoClose() → void
clearUseMarketBasedPrice() → void
clearUseReOpenAfterAutoClose() → void
clearVersionNr() → void
clone() → OfferPayload
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(OfferPayload)) → OfferPayload
Apply updates to a copy of this message.
override
createEmptyInstance() → OfferPayload
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureArbitratorSigner() → NodeAddress
ensureOwnerNodeAddress() → NodeAddress
ensurePubKeyRing() → PubKeyRing
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAmount() → bool
hasArbitratorSignature() → bool
hasArbitratorSigner() → bool
hasBankId() → bool
hasBaseCurrencyCode() → bool
hasBlockHeightAtOfferCreation() → bool
hasBuyerSecurityDepositPct() → bool
hasCounterCurrencyCode() → bool
hasCountryCode() → bool
hasDate() → bool
hasDirection() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasHashOfChallenge() → bool
hasId() → bool
hasIsPrivateOffer() → bool
hasLowerClosePrice() → bool
hasMakerFeePct() → bool
hasMakerPaymentAccountId() → bool
hasMarketPriceMarginPct() → bool
hasMaxTradeLimit() → bool
hasMaxTradePeriod() → bool
hasMinAmount() → bool
hasOwnerNodeAddress() → bool
hasPaymentMethodId() → bool
hasPenaltyFeePct() → bool
hasPrice() → bool
hasProtocolVersion() → bool
hasPubKeyRing() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSellerSecurityDepositPct() → bool
hasTakerFeePct() → bool
hasUpperClosePrice() → bool
hasUseAutoClose() → bool
hasUseMarketBasedPrice() → bool
hasUseReOpenAfterAutoClose() → bool
hasVersionNr() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → OfferPayload
createRepeated() → PbList<OfferPayload>
getDefault() → OfferPayload